!function(){"use strict";jQuery(document).ready(function(e){e(".opening_informations").click(function(t){e(this).siblings(".table_schedule").toggleClass("table_schedule--active"),t.preventDefault()}),e(document).click(function(t){e(".table_schedule").hasClass("table_schedule--active")&&(e(".table_schedule").is(t.target)||e(".opening_informations").is(t.target)||e(".table_schedule td").is(t.target)||e(".table_schedule").toggleClass("table_schedule--active"))}),-1!==window.location.href.indexOf("@@siteadmin-smartweb-controlpanel")&&e("div.container div.statusmessage-error").length>0&&e("div.container div.statusmessage-info").remove()}),$(document).ready(function(){const e=$("#portal-globalnav"),t=$("#portal-globalnav > li > .has_subtree"),n=$("#subsite-navigation li > .has_subtree"),s=$("#subsite-navigation");function a(){e.removeClass("activated"),s.removeClass("activated"),document.body.classList.remove("submenu-open-nav-overflow"),document.documentElement.classList.remove("submenu-open-nav-overflow"),$(".show-nav").removeClass("show-nav"),$(".mask-menu").removeClass("in"),t.attr("inert",""),n.attr("inert","")}t.attr("inert",""),n.attr("inert",""),$(".close-nav").click(function(){a()}),$(document).mouseup(t=>{e.is(t.target)||0!==e.has(t.target).length||s.is(t.target)||0!==s.has(t.target).length||a()}),$("li.has_subtree > a").click(function(){return $(this).closest(e).length>0&&(!$("#portal-globalnav .show-nav").length>0&&($(e).toggleClass("activated"),$(".mask-menu").toggleClass("in"),t.removeAttr("inert")),$(this).parent().toggleClass("show-nav"),$(this).parent().find(".show-nav").toggleClass("show-nav"),$(this).parent().siblings(".show-nav").toggleClass("show-nav"),$(this).parent().find(".activated").toggleClass(".activated"),!$("#portal-globalnav .show-nav").length>0&&a()),$(this).closest(s).length>0&&(!$("#subsite-navigation .show-nav").length>0&&($(s).toggleClass("activated"),document.body.classList.add("submenu-open-nav-overflow"),document.documentElement.classList.add("submenu-open-nav-overflow"),n.removeAttr("inert")),$(this).parent().toggleClass("show-nav"),$(this).parent().find(".show-nav").toggleClass("show-nav"),$(this).parent().siblings(".show-nav").toggleClass("show-nav"),$(this).parent().find(".activated").toggleClass(".activated"),!$("#subsite-navigation .show-nav").length>0&&a()),!1}),$(".prev-nav").click(function(){$(this).closest(".show-nav").toggleClass("show-nav")}),e.on("focusout",function(){setTimeout(function(){e.has(document.activeElement).length||a()},0)})}),document.addEventListener("DOMContentLoaded",function(){const e=document.getElementById("header-actions"),t=document.getElementById("portal-globalnav-collapse");if(!e||!t)return;const n=e.parentNode,s=e.nextSibling;function a(){window.innerWidth<=991?t.contains(e)||t.appendChild(e):e.parentNode!==n&&(s&&s.parentNode===n?n.insertBefore(e,s):n.appendChild(e))}a(),window.addEventListener("resize",a)})}();